@@ -5,7 +5,7 @@
 #  The MIT (X11) License
 
 package WebService::Pixabay;
-$WebService::Pixabay::VERSION = '2.2.2';
+$WebService::Pixabay::VERSION = '2.2.3';
 # ABSTRACT: Perl 5 interface to Pixabay API.
 
 use strict;
@@ -24,7 +24,6 @@ has api_key => (
 
 has '+base_url' => ( default => 'https://pixabay.com/api/' );
 
-
 method image_search(
     : $q              = "yellow flower",
     : $lang           = "en",
@@ -52,7 +51,6 @@ method image_search(
           . "&per_page=$per_page&callback=$callback&pretty=$pretty" );
 }
 
-
 method video_search(
     : $q              = "yellow flower",
     : $lang           = "en",
@@ -92,7 +90,7 @@ WebService::Pixabay - Perl 5 interface to Pixabay API.
 
 =head1 VERSION
 
-version 2.2.2
+version 2.2.3
 
 =head1 SYNOPSIS
 
@@ -166,59 +164,47 @@ version 2.2.2
 
 =over 4
 
-=item image_search( q              => "yellow flower",
-                    lang           => "en",
-                    id             => "",
-                    response_group => "image_details",
-                    image_type     => "all",
-                    orientation    => "all",
-                    category       => "",
-                    min_width      => 0,
-                    min_height     => 0,
-                    editors_choice => "false",
-                    safesearch     => "false",
-                    order          => "popular",
-                    page           => 1,
-                    per_page       => 20,
-                    callback       => "",
-                    pretty         => "false")
+=item C<image_search>
 
 Description: Get image search metadata with default values as shown above.
 
-Parameter: q str A URL encoded search term. If omitted, all images are returned.
- This value may not exceed 100 characters.
- Example: "yellow+flower"
+Parameter: q str A URL encoded search term.
+If omitted, all images are returned.
+This value may not exceed 100 characters.Example: "yellow+flower"
 
 Parameter: lang str Language code of the language to be searched in.
- Accepted values: cs, da, de, en, es, fr, id, it, hu, nl, no, pl, pt, ro, sk, fi, sv, tr, vi, th, bg, ru, el, ja, ko, zh
- Default: "en"
+Accepted values: cs, da, de, en, es, fr, id, it, hu, nl, no, pl, pt, ro, sk, fi, sv, tr, vi, th, bg, ru, el, ja, ko, zh
+Default: "en"
 
-Parameter: id str ID, hash ID, or a comma separated list of values for retrieving specific images. In a comma separated list, IDs and hash IDs cannot be used together.
+Parameter: id str ID, hash ID, or a comma separated list of values for retrieving specific images. In a comma separated
+list, IDs and hash IDs cannot be used together.
 
-Parameter: response_group str Choose between retrieving high resolution images and image details. When selecting details, you can access images up to a dimension of 960 x 720 px.
- Accepted values: "image_details", "high_resolution"
- Default: "image_details"
+Parameter: response_group str Choose between retrieving high resolution images and image details. When selecting details
+, you can access images up to a dimension of 960 x 720 px.
+Accepted values: "image_details", "high_resolution"
+Default: "image_details"
 
 Parameter: image_type str Filter results by image type.
- Accepted values: "all", "photo", "illustration", "vector"
- Default: "all"
+Accepted values: "all", "photo", "illustration", "vector"
+Default: "all"
 
 Parameter: orientation str Whether an image is wider than it is tall, or taller than it is wide.
- Accepted values: "all", "horizontal", "vertical"
- Default: "all"
+Accepted values: "all", "horizontal", "vertical"
+Default: "all"
 
 Parameter: category str Filter results by category.
- Accepted values: fashion, nature, backgrounds, science, education, people, feelings, religion, health, places, animals, industry, food, computer, sports, transportation, travel, buildings, business, music
+Accepted values: fashion, nature, backgrounds, science, education, people, feelings, religion, health, places, animals,
+ industry, food, computer, sports, transportation, travel, buildings, business, music
 
 Parameter: min_width int Minimum image width.
- Default: "0"
+Default: "0"
 
 Parameter: min_height int Minimum image height.
- Default: "0"
+Default: "0"
 
 Parameter: editors_choice bool Select images that have received an Editor's Choice award.
- Accepted values: "true", "false"
- Default: "false"
+Accepted values: "true", "false"
+Default: "false"
 
 Parameter: safesearch bool A flag indicating that only images suitable for all ages should be returned.
  Accepted values: "true", "false"
@@ -243,25 +229,7 @@ Parameter: pretty bool Indent JSON output. This option should not be used in pro
 
 Returns: Image search metadata.
 
-=back
-
-=over 4
-
-=item video_search( q              => "yellow flower",
-                    lang           => "en",
-                    id             => "",
-                    video_type     => "all",
-                    orientation    => "all",
-                    category       => "",
-                    min_width      => 0,
-                    min_height     => 0,
-                    editors_choice => "false",
-                    safesearch     => "false",
-                    order          => "popular",
-                    page           => 1,
-                    per_page       => 20,
-                    callback       => "",
-                    pretty         => "false")
+=item C<video_search>
 
 Description: Get video search metadata with default values as shown above.
 
@@ -273,7 +241,8 @@ Parameter: lang str Language code of the language to be searched in.
  Accepted values: cs, da, de, en, es, fr, id, it, hu, nl, no, pl, pt, ro, sk, fi, sv, tr, vi, th, bg, ru, el, ja, ko, zh
  Default: "en"
 
-Parameter: id str ID, hash ID, or a comma separated list of values for retrieving specific images. In a comma separated list, IDs and hash IDs cannot be used together.
+Parameter: id str ID, hash ID, or a comma separated list of values for retrieving specific images. In a comma separated
+ list, IDs and hash IDs cannot be used together.
 
 Parameter: video_type str Filter results by video type.
  Accepted values: "all", "film", "animation"
@@ -284,7 +253,8 @@ Parameter: orientation str Whether an image is wider than it is tall, or taller
  Default: "all"
 
 Parameter: category str Filter results by category.
- Accepted values: fashion, nature, backgrounds, science, education, people, feelings, religion, health, places, animals, industry, food, computer, sports, transportation, travel, buildings, business, music
+ Accepted values: fashion, nature, backgrounds, science, education, people, feelings, religion, health, places, animals,
+ industry, food, computer, sports, transportation, travel, buildings, business, music
 
 Parameter: min_width int Minimum image width.
  Default: "0"
